
# AUTOGENERATED File do not edit!
# File generated by the profile_tool.py 'compress' command.

from rekall import io_manager


class BuiltInProfiles(io_manager.BuiltInManager):
    data = {
 'Win7SP1x64': {
  'Constants.json': {
   'DRIVER_POOLTAG': 'Dri\xf6',
   'EPROCESS_POOLTAG': 'Pro\xe3',
   'FILE_POOLTAG': 'Fil\xe5',
   'MODULE_POOLTAG': 'MmLd',
   'MUTANT_POOLTAG': 'Mut\xe1',
   'MaxPointer': 281474976710655,
   'PoolAlignment': 16,
   'SYMLINK_POOLTAG': 'Sym\xe2',
   'THREAD_POOLTAG': 'Thr\xe5',
   'default_text_encoding': 'utf-16-le',
  },
  'metadata': {
   'Constants': 'Constants.json',
   'ProfileClass': 'Win7SP1x64',
   'VTypes': 'vtypes.json',
  },
  'vtypes.json': {
   'LIST_ENTRY64': [16, {
    'Blink': [8, ['unsigned long long']],
    'Flink': [0, ['unsigned long long']],
   }],
   '_ALPC_PROCESS_CONTEXT': [32, {
   }],
   '_CHILD_LIST': [8, {
    'Count': [0, ['unsigned long']],
    'List': [4, ['unsigned long']],
   }],
   '_CLIENT_ID': [16, {
    'UniqueProcess': [0, ['pointer64', ['void']]],
    'UniqueThread': [8, ['pointer64', ['void']]],
   }],
   '_CMHIVE': [3048, {
    'FileFullPath': [1752, ['_UNICODE_STRING']],
    'FileUserName': [1768, ['_UNICODE_STRING']],
    'Hive': [0, ['_HHIVE']],
    'HiveList': [1496, ['_LIST_ENTRY']],
    'HiveRootPath': [1784, ['_UNICODE_STRING']],
   }],
   '_CM_KEY_INDEX': [8, {
    'Count': [2, ['unsigned short']],
    'List': [4, ['array', 1, ['unsigned long']]],
    'Signature': [0, ['unsigned short']],
   }],
   '_CM_KEY_NODE': [80, {
    'Flags': [2, ['unsigned short']],
    'LastWriteTime': [4, ['_LARGE_INTEGER']],
    'Name': [76, ['array', 1, ['wchar']]],
    'NameLength': [72, ['unsigned short']],
    'Signature': [0, ['unsigned short']],
    'SubKeyCounts': [20, ['array', 2, ['unsigned long']]],
    'SubKeyLists': [28, ['array', 2, ['unsigned long']]],
    'ValueList': [36, ['_CHILD_LIST']],
   }],
   '_CM_KEY_VALUE': [24, {
    'Data': [8, ['unsigned long']],
    'DataLength': [4, ['unsigned long']],
    'Name': [20, ['array', 1, ['wchar']]],
    'NameLength': [2, ['unsigned short']],
    'Signature': [0, ['unsigned short']],
    'Type': [12, ['unsigned long']],
   }],
   '_CONTROL_AREA': [128, {
    'DereferenceList': [8, ['_LIST_ENTRY']],
    'FilePointer': [64, ['_EX_FAST_REF']],
    'NumberOfMappedViews': [40, ['unsigned long long']],
    'NumberOfPfnReferences': [32, ['unsigned long long']],
    'NumberOfSectionReferences': [24, ['unsigned long long']],
    'NumberOfUserReferences': [48, ['unsigned long long']],
    'Segment': [0, ['pointer64', ['_SEGMENT']]],
    'WaitingForDeletion': [80, ['pointer64', ['_MI_SECTION_CREATION_GATE']]],
    'u': [56, ['__unnamed_157b']],
   }],
   '_DBGKD_DEBUG_DATA_HEADER64': [24, {
    'List': [0, ['LIST_ENTRY64']],
    'OwnerTag': [16, ['String', {
     'length': 4,
    }]],
   }],
   '_DEVICE_OBJECT': [336, {
    'AttachedDevice': [24, ['pointer64', ['_DEVICE_OBJECT']]],
    'DeviceType': [72, ['unsigned long']],
    'DriverObject': [8, ['pointer64', ['_DRIVER_OBJECT']]],
    'NextDevice': [16, ['pointer64', ['_DEVICE_OBJECT']]],
   }],
   '_DISPATCHER_HEADER': [24, {
    'SignalState': [4, ['long']],
    'Type': [0, ['unsigned char']],
   }],
   '_DRIVER_EXTENSION': [56, {
    'ServiceKeyName': [24, ['_UNICODE_STRING']],
   }],
   '_DRIVER_OBJECT': [336, {
    'DeviceObject': [8, ['pointer64', ['_DEVICE_OBJECT']]],
    'DriverName': [56, ['_UNICODE_STRING']],
    'DriverSize': [32, ['unsigned long']],
    'DriverStart': [24, ['pointer64', ['void']]],
    'DriverStartIo': [96, ['pointer64', ['void']]],
    'MajorFunction': [112, ['array', 28, ['pointer64', ['void']]]],
   }],
   '_DUAL': [632, {
    'Length': [0, ['unsigned long']],
    'Map': [8, ['pointer64', ['_HMAP_DIRECTORY']]],
   }],
   '_EPROCESS': [1232, {
    'AccountingFolded': [1084, ['BitField', {
     'end_bit': 2,
     'native_type': 'unsigned long',
     'start_bit': 1,
    }]],
    'ActiveProcessLinks': [392, ['_LIST_ENTRY']],
    'ActiveThreads': [808, ['unsigned long']],
    'ActiveThreadsHighWatermark': [1212, ['unsigned long']],
    'AddressCreationLock': [536, ['_EX_PUSH_LOCK']],
    'AddressSpaceInitialized': [1088, ['BitField', {
     'end_bit': 12,
     'native_type': 'unsigned long',
     'start_bit': 10,
    }]],
    'AffinityPermanent': [1084, ['BitField', {
     'end_bit': 19,
     'native_type': 'unsigned long',
     'start_bit': 18,
    }]],
    'AffinityUpdateEnable': [1084, ['BitField', {
     'end_bit': 20,
     'native_type': 'unsigned long',
     'start_bit': 19,
    }]],
    'AlpcContext': [1160, ['_ALPC_PROCESS_CONTEXT']],
    'AweInfo': [904, ['pointer64', ['void']]],
    'BreakOnTermination': [1088, ['BitField', {
     'end_bit': 14,
     'native_type': 'unsigned long',
     'start_bit': 13,
    }]],
    'CloneRoot': [576, ['pointer64', ['void']]],
    'CommitCharge': [440, ['unsigned long long']],
    'CommitChargeLimit': [888, ['unsigned long long']],
    'CommitChargePeak': [896, ['unsigned long long']],
    'ConsoleHostProcess': [680, ['unsigned long long']],
    'Cookie': [632, ['unsigned long']],
    'CpuQuotaBlock': [456, ['pointer64', ['_PS_CPU_QUOTA_BLOCK']]],
    'CreateReported': [1088, ['BitField', {
     'end_bit': 1,
     'native_type': 'unsigned long',
     'start_bit': 0,
    }]],
    'CreateTime': [360, ['_LARGE_INTEGER']],
    'CrossSessionCreate': [1088, ['BitField', {
     'end_bit': 26,
     'native_type': 'unsigned long',
     'start_bit': 25,
    }]],
    'DebugPort': [496, ['pointer64', ['void']]],
    'DefaultHardErrorProcessing': [816, ['unsigned long']],
    'DefaultIoPriority': [1088, ['BitField', {
     'end_bit': 30,
     'native_type': 'unsigned long',
     'start_bit': 27,
    }]],
    'DefaultPagePriority': [1084, ['BitField', {
     'end_bit': 15,
     'native_type': 'unsigned long',
     'start_bit': 12,
    }]],
    'DeprioritizeViews': [1088, ['BitField', {
     'end_bit': 15,
     'native_type': 'unsigned long',
     'start_bit': 14,
    }]],
    'DeviceMap': [688, ['pointer64', ['void']]],
    'EtwDataSource': [696, ['pointer64', ['void']]],
    'ExceptionPortData': [504, ['pointer64', ['void']]],
    'ExceptionPortState': [504, ['BitField', {
     'end_bit': 3,
     'native_type': 'unsigned long long',
     'start_bit': 0,
    }]],
    'ExceptionPortValue': [504, ['unsigned long long']],
    'ExitProcessReported': [1084, ['BitField', {
     'end_bit': 4,
     'native_type': 'unsigned long',
     'start_bit': 3,
    }]],
    'ExitStatus': [1092, ['long']],
    'ExitTime': [368, ['_LARGE_INTEGER']],
    'ExplicitAffinity': [1084, ['BitField', {
     'end_bit': 22,
     'native_type': 'unsigned long',
     'start_bit': 21,
    }]],
    'Filler': [720, ['unsigned long long']],
    'Flags': [1088, ['unsigned long']],
    'Flags2': [1084, ['unsigned long']],
    'ForkFailed': [1088, ['BitField', {
     'end_bit': 9,
     'native_type': 'unsigned long',
     'start_bit': 8,
    }]],
    'ForkInProgress': [552, ['pointer64', ['_ETHREAD']]],
    'FreeTebHint': [704, ['pointer64', ['void']]],
    'FreeUmsTebHint': [712, ['pointer64', ['void']]],
    'HandleTableRundown': [1084, ['BitField', {
     'end_bit': 8,
     'native_type': 'unsigned long',
     'start_bit': 7,
    }]],
    'HardwareTrigger': [560, ['unsigned long long']],
    'HasAddressSpace': [1088, ['BitField', {
     'end_bit': 19,
     'native_type': 'unsigned long',
     'start_bit': 18,
    }]],
    'HighestUserAddress': [1072, ['pointer64', ['void']]],
    'ImageFileName': [736, ['array', 15, ['unsigned char']]],
    'ImageNotifyDone': [1088, ['BitField', {
     'end_bit': 23,
     'native_type': 'unsigned long',
     'start_bit': 22,
    }]],
    'ImagePathHash': [812, ['unsigned long']],
    'InheritedFromUniqueProcessId': [656, ['pointer64', ['void']]],
    'InjectInpageErrors': [1088, ['BitField', {
     'end_bit': 21,
     'native_type': 'unsigned long',
     'start_bit': 20,
    }]],
    'Job': [608, ['pointer64', ['_EJOB']]],
    'JobLinks': [752, ['_LIST_ENTRY']],
    'JobNotReallyActive': [1084, ['BitField', {
     'end_bit': 1,
     'native_type': 'unsigned long',
     'start_bit': 0,
    }]],
    'LastReportMemory': [1084, ['BitField', {
     'end_bit': 6,
     'native_type': 'unsigned long',
     'start_bit': 5,
    }]],
    'LastThreadExitStatus': [820, ['long']],
    'LaunchPrefetched': [1088, ['BitField', {
     'end_bit': 20,
     'native_type': 'unsigned long',
     'start_bit': 19,
    }]],
    'LdtInformation': [664, ['pointer64', ['void']]],
    'LockedPagesList': [768, ['pointer64', ['void']]],
    'MmProcessLinks': [1056, ['_LIST_ENTRY']],
    'ModifiedPageCount': [1080, ['unsigned long']],
    'NeedsHandleRundown': [1084, ['BitField', {
     'end_bit': 9,
     'native_type': 'unsigned long',
     'start_bit': 8,
    }]],
    'NewProcessReported': [1084, ['BitField', {
     'end_bit': 3,
     'native_type': 'unsigned long',
     'start_bit': 2,
    }]],
    'NoDebugInherit': [1088, ['BitField', {
     'end_bit': 2,
     'native_type': 'unsigned long',
     'start_bit': 1,
    }]],
    'NumaAware': [1084, ['BitField', {
     'end_bit': 11,
     'native_type': 'unsigned long',
     'start_bit': 10,
    }]],
    'NumberOfLockedPages': [592, ['unsigned long long']],
    'NumberOfPrivatePages': [584, ['unsigned long long']],
    'ObjectTable': [512, ['pointer64', ['_HANDLE_TABLE']]],
    'OtherOperationCount': [856, ['_LARGE_INTEGER']],
    'OtherTransferCount': [880, ['_LARGE_INTEGER']],
    'OutswapEnabled': [1088, ['BitField', {
     'end_bit': 7,
     'native_type': 'unsigned long',
     'start_bit': 6,
    }]],
    'Outswapped': [1088, ['BitField', {
     'end_bit': 8,
     'native_type': 'unsigned long',
     'start_bit': 7,
    }]],
    'OverrideAddressSpace': [1088, ['BitField', {
     'end_bit': 18,
     'native_type': 'unsigned long',
     'start_bit': 17,
    }]],
    'PageDirectoryPte': [720, ['_HARDWARE_PTE']],
    'Pcb': [0, ['_KPROCESS']],
    'PdeUpdateNeeded': [1088, ['BitField', {
     'end_bit': 24,
     'native_type': 'unsigned long',
     'start_bit': 23,
    }]],
    'PeakVirtualSize': [464, ['unsigned long long']],
    'Peb': [824, ['pointer64', ['_PEB']]],
    'PhysicalVadRoot': [568, ['pointer64', ['_MM_AVL_TABLE']]],
    'PrefetchTrace': [832, ['_EX_FAST_REF']],
    'PrimaryTokenFrozen': [1084, ['BitField', {
     'end_bit': 16,
     'native_type': 'unsigned long',
     'start_bit': 15,
    }]],
    'PriorityClass': [751, ['unsigned char']],
    'ProcessDelete': [1088, ['BitField', {
     'end_bit': 4,
     'native_type': 'unsigned long',
     'start_bit': 3,
    }]],
    'ProcessExiting': [1088, ['BitField', {
     'end_bit': 3,
     'native_type': 'unsigned long',
     'start_bit': 2,
    }]],
    'ProcessInSession': [1088, ['BitField', {
     'end_bit': 17,
     'native_type': 'unsigned long',
     'start_bit': 16,
    }]],
    'ProcessInserted': [1088, ['BitField', {
     'end_bit': 27,
     'native_type': 'unsigned long',
     'start_bit': 26,
    }]],
    'ProcessLock': [352, ['_EX_PUSH_LOCK']],
    'ProcessQuotaPeak': [424, ['array', 2, ['unsigned long long']]],
    'ProcessQuotaUsage': [408, ['array', 2, ['unsigned long long']]],
    'ProcessSelfDelete': [1088, ['BitField', {
     'end_bit': 31,
     'native_type': 'unsigned long',
     'start_bit': 30,
    }]],
    'ProcessVerifierTarget': [1084, ['BitField', {
     'end_bit': 17,
     'native_type': 'unsigned long',
     'start_bit': 16,
    }]],
    'PropagateNode': [1084, ['BitField', {
     'end_bit': 21,
     'native_type': 'unsigned long',
     'start_bit': 20,
    }]],
    'ProtectedProcess': [1084, ['BitField', {
     'end_bit': 12,
     'native_type': 'unsigned long',
     'start_bit': 11,
    }]],
    'QuotaBlock': [448, ['pointer64', ['_EPROCESS_QUOTA_BLOCK']]],
    'ReadOperationCount': [840, ['_LARGE_INTEGER']],
    'ReadTransferCount': [864, ['_LARGE_INTEGER']],
    'RefTraceEnabled': [1084, ['BitField', {
     'end_bit': 10,
     'native_type': 'unsigned long',
     'start_bit': 9,
    }]],
    'ReportCommitChanges': [1084, ['BitField', {
     'end_bit': 5,
     'native_type': 'unsigned long',
     'start_bit': 4,
    }]],
    'ReportPhysicalPageChanges': [1084, ['BitField', {
     'end_bit': 7,
     'native_type': 'unsigned long',
     'start_bit': 6,
    }]],
    'RequestedTimerResolution': [1208, ['unsigned long']],
    'RotateInProgress': [544, ['pointer64', ['_ETHREAD']]],
    'RundownProtect': [376, ['_EX_RUNDOWN_REF']],
    'SeAuditProcessCreationInfo': [912, ['_SE_AUDIT_PROCESS_CREATION_INFO']],
    'SectionBaseAddress': [624, ['pointer64', ['void']]],
    'SectionObject': [616, ['pointer64', ['void']]],
    'SecurityPort': [792, ['pointer64', ['void']]],
    'Session': [728, ['pointer64', ['void']]],
    'SessionProcessLinks': [480, ['_LIST_ENTRY']],
    'SetTimerResolution': [1088, ['BitField', {
     'end_bit': 13,
     'native_type': 'unsigned long',
     'start_bit': 12,
    }]],
    'SetTimerResolutionLink': [1088, ['BitField', {
     'end_bit': 32,
     'native_type': 'unsigned long',
     'start_bit': 31,
    }]],
    'SmallestTimerResolution': [1216, ['unsigned long']],
    'Spare': [672, ['pointer64', ['void']]],
    'StackRandomizationDisabled': [1084, ['BitField', {
     'end_bit': 18,
     'native_type': 'unsigned long',
     'start_bit': 17,
    }]],
    'ThreadListHead': [776, ['_LIST_ENTRY']],
    'TimerResolutionLink': [1192, ['_LIST_ENTRY']],
    'TimerResolutionStackRecord': [1224, ['pointer64', ['_PO_DIAG_STACK_RECORD']]],
    'Token': [520, ['_EX_FAST_REF']],
    'UmsScheduledThreads': [636, ['unsigned long']],
    'UniqueProcessId': [384, ['pointer64', ['void']]],
    'VadRoot': [1096, ['_MM_AVL_TABLE']],
    'VdmAllowed': [1088, ['BitField', {
     'end_bit': 25,
     'native_type': 'unsigned long',
     'start_bit': 24,
    }]],
    'VirtualSize': [472, ['unsigned long long']],
    'Vm': [920, ['_MMSUPPORT']],
    'VmDeleted': [1088, ['BitField', {
     'end_bit': 6,
     'native_type': 'unsigned long',
     'start_bit': 5,
    }]],
    'VmTopDown': [1088, ['BitField', {
     'end_bit': 22,
     'native_type': 'unsigned long',
     'start_bit': 21,
    }]],
    'Win32Process': [600, ['pointer64', ['void']]],
    'Win32WindowStation': [648, ['pointer64', ['void']]],
    'WorkingSetPage': [528, ['unsigned long long']],
    'WorkingSetWatch': [640, ['pointer64', ['_PAGEFAULT_HISTORY']]],
    'Wow64Process': [800, ['pointer64', ['void']]],
    'Wow64SplitPages': [1088, ['BitField', {
     'end_bit': 5,
     'native_type': 'unsigned long',
     'start_bit': 4,
    }]],
    'Wow64VaSpace4Gb': [1088, ['BitField', {
     'end_bit': 10,
     'native_type': 'unsigned long',
     'start_bit': 9,
    }]],
    'WriteOperationCount': [848, ['_LARGE_INTEGER']],
    'WriteTransferCount': [872, ['_LARGE_INTEGER']],
    'WriteWatch': [1088, ['BitField', {
     'end_bit': 16,
     'native_type': 'unsigned long',
     'start_bit': 15,
    }]],
   }],
   '_ETHREAD': [1176, {
    'Cid': [944, ['_CLIENT_ID']],
    'CreateTime': [864, ['_LARGE_INTEGER']],
    'ExitTime': [872, ['_LARGE_INTEGER']],
    'KeyedWaitSemaphore': [960, ['_KSEMAPHORE']],
    'StartAddress': [904, ['pointer64', ['void']]],
    'Tcb': [0, ['_KTHREAD']],
   }],
   '_EX_FAST_REF': [8, {
    'Object': [0, ['pointer64', ['void']]],
   }],
   '_EX_PUSH_LOCK': [8, {
   }],
   '_EX_RUNDOWN_REF': [8, {
   }],
   '_FILE_OBJECT': [216, {
    'DeleteAccess': [76, ['unsigned char']],
    'FileName': [88, ['_UNICODE_STRING']],
    'ReadAccess': [74, ['unsigned char']],
    'SharedDelete': [79, ['unsigned char']],
    'SharedRead': [77, ['unsigned char']],
    'SharedWrite': [78, ['unsigned char']],
    'WriteAccess': [75, ['unsigned char']],
   }],
   '_HANDLE_TABLE': [104, {
    'HandleCount': [88, ['unsigned long']],
    'TableCode': [0, ['unsigned long long']],
   }],
   '_HANDLE_TABLE_ENTRY': [16, {
    'Object': [0, ['pointer64', ['void']]],
   }],
   '_HARDWARE_PTE': [8, {
   }],
   '_HHIVE': [1432, {
    'BaseBlock': [80, ['pointer64', ['_HBASE_BLOCK']]],
    'Flat': [120, ['unsigned char']],
    'Signature': [0, ['unsigned long']],
    'Storage': [168, ['array', 2, ['_DUAL']]],
   }],
   '_HMAP_DIRECTORY': [8192, {
    'Directory': [0, ['array', 1024, ['pointer64', ['_HMAP_TABLE']]]],
   }],
   '_HMAP_ENTRY': [32, {
    'BlockAddress': [0, ['unsigned long long']],
   }],
   '_HMAP_TABLE': [16384, {
    'Table': [0, ['array', 512, ['_HMAP_ENTRY']]],
   }],
   '_KAPC_STATE': [48, {
    'Process': [32, ['pointer64', ['_KPROCESS']]],
   }],
   '_KDDEBUGGER_DATA64': [832, {
    'Header': [0, ['_DBGKD_DEBUG_DATA_HEADER64']],
    'MmPfnDatabase': [192, ['unsigned long long']],
    'PsActiveProcessHead': [80, ['unsigned long long']],
    'PsLoadedModuleList': [72, ['unsigned long long']],
    'PspCidTable': [88, ['unsigned long long']],
   }],
   '_KMUTANT': [56, {
    'Header': [0, ['_DISPATCHER_HEADER']],
    'OwnerThread': [40, ['pointer64', ['_KTHREAD']]],
   }],
   '_KPCR': [20096, {
    'GdtBase': [0, ['pointer64', ['_KGDTENTRY64']]],
    'IdtBase': [56, ['pointer64', ['_KIDTENTRY64']]],
    'KdVersionBlock': [264, ['pointer64', ['void']]],
    'Prcb': [384, ['_KPRCB']],
    'Self': [24, ['pointer64', ['_KPCR']]],
   }],
   '_KPRCB': [19712, {
    'CurrentThread': [8, ['pointer64', ['_KTHREAD']]],
    'IdleThread': [24, ['pointer64', ['_KTHREAD']]],
    'MHz': [1524, ['unsigned long']],
    'NextThread': [16, ['pointer64', ['_KTHREAD']]],
    'Number': [36, ['unsigned long']],
    'ProcessorState': [64, ['_KPROCESSOR_STATE']],
    'VendorString': [19384, ['array', 13, ['unsigned char']]],
    'WaitListHead': [17536, ['_LIST_ENTRY']],
   }],
   '_KPROCESS': [352, {
    'DirectoryTableBase': [40, ['unsigned long long']],
    'ThreadListHead': [48, ['_LIST_ENTRY']],
   }],
   '_KPROCESSOR_STATE': [1456, {
    'SpecialRegisters': [0, ['_KSPECIAL_REGISTERS']],
   }],
   '_KSEMAPHORE': [32, {
    'Header': [0, ['_DISPATCHER_HEADER']],
   }],
   '_KSPECIAL_REGISTERS': [216, {
    'Cr3': [16, ['unsigned long long']],
   }],
   '_KTHREAD': [864, {
    'ApcState': [80, ['_KAPC_STATE']],
    'Process': [528, ['pointer64', ['_KPROCESS']]],
    'SuspendSemaphore': [728, ['_KSEMAPHORE']],
    'ThreadListEntry': [760, ['_LIST_ENTRY']],
    'WaitListEntry': [160, ['_LIST_ENTRY']],
   }],
   '_LARGE_INTEGER': [8, {
   }],
   '_LDR_DATA_TABLE_ENTRY': [224, {
    'BaseDllName': [88, ['_UNICODE_STRING']],
    'DllBase': [48, ['pointer64', ['void']]],
    'FullDllName': [72, ['_UNICODE_STRING']],
    'InInitializationOrderLinks': [32, ['_LIST_ENTRY']],
    'InLoadOrderLinks': [0, ['_LIST_ENTRY']],
    'InMemoryOrderLinks': [16, ['_LIST_ENTRY']],
    'SizeOfImage': [64, ['unsigned long']],
   }],
   '_LIST_ENTRY': [16, {
    'Blink': [8, ['pointer64', ['_LIST_ENTRY']]],
    'Flink': [0, ['pointer64', ['_LIST_ENTRY']]],
   }],
   '_MMADDRESS_NODE': [40, {
    'LeftChild': [8, ['pointer64', ['_MMADDRESS_NODE']]],
    'RightChild': [16, ['pointer64', ['_MMADDRESS_NODE']]],
   }],
   '_MMPFN': [48, {
    'PteAddress': [16, ['pointer64', ['_MMPTE']]],
    'u1': [0, ['__unnamed_152f']],
    'u3': [24, ['__unnamed_1536']],
    'u4': [40, ['__unnamed_153e']],
   }],
   '_MMPFNENTRY': [2, {
    'PageLocation': [0, ['BitField', {
     'end_bit': 3,
     'native_type': 'unsigned char',
     'start_bit': 0,
    }]],
   }],
   '_MMSECTION_FLAGS': [4, {
    'Accessed': [0, ['BitField', {
     'end_bit': 15,
     'native_type': 'unsigned long',
     'start_bit': 14,
    }]],
    'Based': [0, ['BitField', {
     'end_bit': 7,
     'native_type': 'unsigned long',
     'start_bit': 6,
    }]],
    'BeingCreated': [0, ['BitField', {
     'end_bit': 2,
     'native_type': 'unsigned long',
     'start_bit': 1,
    }]],
    'BeingDeleted': [0, ['BitField', {
     'end_bit': 1,
     'native_type': 'unsigned long',
     'start_bit': 0,
    }]],
    'BeingPurged': [0, ['BitField', {
     'end_bit': 3,
     'native_type': 'unsigned long',
     'start_bit': 2,
    }]],
    'CollidedFlush': [0, ['BitField', {
     'end_bit': 23,
     'native_type': 'unsigned long',
     'start_bit': 22,
    }]],
    'Commit': [0, ['BitField', {
     'end_bit': 14,
     'native_type': 'unsigned long',
     'start_bit': 13,
    }]],
    'CopyOnWrite': [0, ['BitField', {
     'end_bit': 12,
     'native_type': 'unsigned long',
     'start_bit': 11,
    }]],
    'DeleteOnClose': [0, ['BitField', {
     'end_bit': 19,
     'native_type': 'unsigned long',
     'start_bit': 18,
    }]],
    'FailAllIo': [0, ['BitField', {
     'end_bit': 5,
     'native_type': 'unsigned long',
     'start_bit': 4,
    }]],
    'File': [0, ['BitField', {
     'end_bit': 8,
     'native_type': 'unsigned long',
     'start_bit': 7,
    }]],
    'FilePointerNull': [0, ['BitField', {
     'end_bit': 20,
     'native_type': 'unsigned long',
     'start_bit': 19,
    }]],
    'GlobalMemory': [0, ['BitField', {
     'end_bit': 18,
     'native_type': 'unsigned long',
     'start_bit': 17,
    }]],
    'GlobalOnlyPerSession': [0, ['BitField', {
     'end_bit': 21,
     'native_type': 'unsigned long',
     'start_bit': 20,
    }]],
    'Image': [0, ['BitField', {
     'end_bit': 6,
     'native_type': 'unsigned long',
     'start_bit': 5,
    }]],
    'Networked': [0, ['BitField', {
     'end_bit': 9,
     'native_type': 'unsigned long',
     'start_bit': 8,
    }]],
    'NoChange': [0, ['BitField', {
     'end_bit': 24,
     'native_type': 'unsigned long',
     'start_bit': 23,
    }]],
    'NoModifiedWriting': [0, ['BitField', {
     'end_bit': 4,
     'native_type': 'unsigned long',
     'start_bit': 3,
    }]],
    'PhysicalMemory': [0, ['BitField', {
     'end_bit': 11,
     'native_type': 'unsigned long',
     'start_bit': 10,
    }]],
    'PreferredNode': [0, ['BitField', {
     'end_bit': 32,
     'native_type': 'unsigned long',
     'start_bit': 26,
    }]],
    'Reserve': [0, ['BitField', {
     'end_bit': 13,
     'native_type': 'unsigned long',
     'start_bit': 12,
    }]],
    'Rom': [0, ['BitField', {
     'end_bit': 10,
     'native_type': 'unsigned long',
     'start_bit': 9,
    }]],
    'SetMappedFileIoComplete': [0, ['BitField', {
     'end_bit': 22,
     'native_type': 'unsigned long',
     'start_bit': 21,
    }]],
    'Spare': [0, ['BitField', {
     'end_bit': 25,
     'native_type': 'unsigned long',
     'start_bit': 24,
    }]],
    'UserReference': [0, ['BitField', {
     'end_bit': 17,
     'native_type': 'unsigned long',
     'start_bit': 16,
    }]],
    'UserWritable': [0, ['BitField', {
     'end_bit': 26,
     'native_type': 'unsigned long',
     'start_bit': 25,
    }]],
    'WasPurged': [0, ['BitField', {
     'end_bit': 16,
     'native_type': 'unsigned long',
     'start_bit': 15,
    }]],
   }],
   '_MMSUPPORT': [136, {
   }],
   '_MMVAD': [120, {
    'EndingVpn': [32, ['unsigned long long']],
    'FirstPrototypePte': [80, ['pointer64', ['_MMPTE']]],
    'LastContiguousPte': [88, ['pointer64', ['_MMPTE']]],
    'LeftChild': [8, ['pointer64', ['_MMVAD']]],
    'RightChild': [16, ['pointer64', ['_MMVAD']]],
    'StartingVpn': [24, ['unsigned long long']],
    'Subsection': [72, ['pointer64', ['_SUBSECTION']]],
    'u': [40, ['__unnamed_15c2']],
    'u2': [64, ['__unnamed_15d2']],
   }],
   '_MMVAD_FLAGS': [8, {
    'CommitCharge': [0, ['BitField', {
     'end_bit': 51,
     'native_type': 'unsigned long long',
     'start_bit': 0,
    }]],
    'MemCommit': [0, ['BitField', {
     'end_bit': 56,
     'native_type': 'unsigned long long',
     'start_bit': 55,
    }]],
    'NoChange': [0, ['BitField', {
     'end_bit': 52,
     'native_type': 'unsigned long long',
     'start_bit': 51,
    }]],
    'PrivateMemory': [0, ['BitField', {
     'end_bit': 64,
     'native_type': 'unsigned long long',
     'start_bit': 63,
    }]],
    'Protection': [0, ['BitField', {
     'end_bit': 61,
     'native_type': 'unsigned long long',
     'start_bit': 56,
    }]],
    'Spare': [0, ['BitField', {
     'end_bit': 63,
     'native_type': 'unsigned long long',
     'start_bit': 61,
    }]],
    'VadType': [0, ['BitField', {
     'end_bit': 55,
     'native_type': 'unsigned long long',
     'start_bit': 52,
    }]],
   }],
   '_MMVAD_FLAGS2': [4, {
    'CopyOnWrite': [0, ['BitField', {
     'end_bit': 32,
     'native_type': 'unsigned long',
     'start_bit': 31,
    }]],
    'ExtendableFile': [0, ['BitField', {
     'end_bit': 30,
     'native_type': 'unsigned long',
     'start_bit': 29,
    }]],
    'FileOffset': [0, ['BitField', {
     'end_bit': 24,
     'native_type': 'unsigned long',
     'start_bit': 0,
    }]],
    'Inherit': [0, ['BitField', {
     'end_bit': 31,
     'native_type': 'unsigned long',
     'start_bit': 30,
    }]],
    'LongVad': [0, ['BitField', {
     'end_bit': 29,
     'native_type': 'unsigned long',
     'start_bit': 28,
    }]],
    'MultipleSecured': [0, ['BitField', {
     'end_bit': 27,
     'native_type': 'unsigned long',
     'start_bit': 26,
    }]],
    'OneSecured': [0, ['BitField', {
     'end_bit': 26,
     'native_type': 'unsigned long',
     'start_bit': 25,
    }]],
    'SecNoChange': [0, ['BitField', {
     'end_bit': 25,
     'native_type': 'unsigned long',
     'start_bit': 24,
    }]],
    'Spare': [0, ['BitField', {
     'end_bit': 28,
     'native_type': 'unsigned long',
     'start_bit': 27,
    }]],
   }],
   '_MMVAD_LONG': [144, {
    'EndingVpn': [32, ['unsigned long long']],
    'FirstPrototypePte': [80, ['pointer64', ['_MMPTE']]],
    'LastContiguousPte': [88, ['pointer64', ['_MMPTE']]],
    'LeftChild': [8, ['pointer64', ['_MMVAD']]],
    'RightChild': [16, ['pointer64', ['_MMVAD']]],
    'StartingVpn': [24, ['unsigned long long']],
    'Subsection': [72, ['pointer64', ['_SUBSECTION']]],
    'u': [40, ['__unnamed_15c2']],
    'u2': [64, ['__unnamed_15d2']],
   }],
   '_MMVAD_SHORT': [64, {
    'EndingVpn': [32, ['unsigned long long']],
    'LeftChild': [8, ['pointer64', ['_MMVAD']]],
    'RightChild': [16, ['pointer64', ['_MMVAD']]],
    'StartingVpn': [24, ['unsigned long long']],
    'u': [40, ['__unnamed_15c2']],
   }],
   '_MM_AVL_TABLE': [64, {
    'BalancedRoot': [0, ['_MMADDRESS_NODE']],
   }],
   '_MM_SESSION_SPACE': [8064, {
    'SessionId': [8, ['unsigned long']],
   }],
   '_OBJECT_HANDLE_COUNT_ENTRY': [16, {
    'Process': [0, ['pointer64', ['_EPROCESS']]],
   }],
   '_OBJECT_HEADER': [56, {
    'Body': [48, ['_QUAD']],
    'HandleCount': [8, ['long long']],
    'InfoMask': [26, ['unsigned char']],
    'PointerCount': [0, ['long long']],
    'TypeIndex': [24, ['unsigned char']],
   }],
   '_OBJECT_HEADER_CREATOR_INFO': [32, {
   }],
   '_OBJECT_HEADER_HANDLE_INFO': [16, {
    'SingleEntry': [0, ['_OBJECT_HANDLE_COUNT_ENTRY']],
   }],
   '_OBJECT_HEADER_NAME_INFO': [32, {
    'Name': [8, ['_UNICODE_STRING']],
   }],
   '_OBJECT_HEADER_PROCESS_INFO': [16, {
   }],
   '_OBJECT_HEADER_QUOTA_INFO': [32, {
   }],
   '_OBJECT_SYMBOLIC_LINK': [32, {
    'CreationTime': [0, ['_LARGE_INTEGER']],
    'LinkTarget': [8, ['_UNICODE_STRING']],
   }],
   '_PEB': [896, {
    'CSDVersion': [744, ['_UNICODE_STRING']],
    'ImageBaseAddress': [16, ['pointer64', ['void']]],
    'Ldr': [24, ['pointer64', ['_PEB_LDR_DATA']]],
    'ProcessParameters': [32, ['pointer64', ['_RTL_USER_PROCESS_PARAMETERS']]],
   }],
   '_PEB_LDR_DATA': [88, {
    'InInitializationOrderModuleList': [48, ['_LIST_ENTRY']],
    'InLoadOrderModuleList': [16, ['_LIST_ENTRY']],
    'InMemoryOrderModuleList': [32, ['_LIST_ENTRY']],
   }],
   '_POOL_HEADER': [16, {
    'BlockSize': [0, ['BitField', {
     'end_bit': 24,
     'native_type': 'unsigned long',
     'start_bit': 16,
    }]],
    'PoolIndex': [0, ['BitField', {
     'end_bit': 16,
     'native_type': 'unsigned long',
     'start_bit': 8,
    }]],
    'PoolTag': [4, ['unsigned long']],
    'PoolType': [0, ['BitField', {
     'end_bit': 32,
     'native_type': 'unsigned long',
     'start_bit': 24,
    }]],
   }],
   '_QUAD': [8, {
   }],
   '_RTL_USER_PROCESS_PARAMETERS': [1024, {
    'CommandLine': [112, ['_UNICODE_STRING']],
    'Environment': [128, ['pointer64', ['void']]],
   }],
   '_SE_AUDIT_PROCESS_CREATION_INFO': [8, {
   }],
   '_SID': [12, {
    'IdentifierAuthority': [2, ['_SID_IDENTIFIER_AUTHORITY']],
    'Revision': [0, ['unsigned char']],
    'SubAuthority': [8, ['array', 1, ['unsigned long']]],
    'SubAuthorityCount': [1, ['unsigned char']],
   }],
   '_SID_AND_ATTRIBUTES': [16, {
    'Sid': [0, ['pointer64', ['void']]],
   }],
   '_SID_IDENTIFIER_AUTHORITY': [6, {
    'Value': [0, ['array', 6, ['unsigned char']]],
   }],
   '_SUBSECTION': [56, {
    'ControlArea': [0, ['pointer64', ['_CONTROL_AREA']]],
   }],
   '_TOKEN': [784, {
    'UserAndGroupCount': [120, ['unsigned long']],
    'UserAndGroups': [144, ['pointer64', ['_SID_AND_ATTRIBUTES']]],
   }],
   '_UNICODE_STRING': [16, {
    'Buffer': [8, ['pointer64', ['unsigned short']]],
    'Length': [0, ['unsigned short']],
   }],
   '__unnamed_152f': [8, {
    'Flink': [0, ['unsigned long long']],
   }],
   '__unnamed_1536': [4, {
    'e1': [2, ['_MMPFNENTRY']],
   }],
   '__unnamed_153e': [8, {
    'PteFrame': [0, ['BitField', {
     'end_bit': 52,
     'native_type': 'unsigned long long',
     'start_bit': 0,
    }]],
   }],
   '__unnamed_157b': [4, {
    'Flags': [0, ['_MMSECTION_FLAGS']],
   }],
   '__unnamed_15c2': [8, {
    'VadFlags': [0, ['_MMVAD_FLAGS']],
   }],
   '__unnamed_15d2': [4, {
    'VadFlags2': [0, ['_MMVAD_FLAGS2']],
   }],
  },
 },
 'WinXPSP2x86': {
  'metadata': {
   'Constants': 'Constants.json',
   'ProfileClass': 'WinXPSP2x86',
   'VTypes': 'vtypes.json',
  },
  'vtypes.json': {
   'LIST_ENTRY32': [8, {
    'Blink': [4, ['unsigned long']],
    'Flink': [0, ['unsigned long']],
   }],
   'LIST_ENTRY64': [16, {
   }],
   '_CLIENT_ID': [8, {
    'UniqueProcess': [0, ['pointer', ['void']]],
    'UniqueThread': [4, ['pointer', ['void']]],
   }],
   '_CMHIVE': [1180, {
    'FileFullPath': [584, ['_UNICODE_STRING']],
    'FileUserName': [592, ['_UNICODE_STRING']],
    'Hive': [0, ['_HHIVE']],
    'HiveList': [548, ['_LIST_ENTRY']],
   }],
   '_CM_KEY_BODY': [68, {
    'KeyControlBlock': [4, ['pointer', ['_CM_KEY_CONTROL_BLOCK']]],
   }],
   '_CM_KEY_CONTROL_BLOCK': [72, {
    'NameBlock': [28, ['pointer', ['_CM_NAME_CONTROL_BLOCK']]],
    'ParentKcb': [24, ['pointer', ['_CM_KEY_CONTROL_BLOCK']]],
   }],
   '_CM_KEY_INDEX': [8, {
    'Count': [2, ['unsigned short']],
    'List': [4, ['array', 1, ['unsigned long']]],
    'Signature': [0, ['unsigned short']],
   }],
   '_CM_KEY_NODE': [80, {
    'Flags': [2, ['unsigned short']],
    'LastWriteTime': [4, ['_LARGE_INTEGER']],
    'Signature': [0, ['unsigned short']],
    'SubKeyCounts': [20, ['array', 2, ['unsigned long']]],
    'SubKeyLists': [28, ['array', 2, ['unsigned long']]],
   }],
   '_CM_NAME_CONTROL_BLOCK': [16, {
    'Name': [14, ['array', 1, ['unsigned short']]],
    'NameLength': [12, ['unsigned short']],
   }],
   '_CONTROL_AREA': [48, {
    'DereferenceList': [4, ['_LIST_ENTRY']],
    'FilePointer': [36, ['pointer', ['_FILE_OBJECT']]],
    'NumberOfMappedViews': [20, ['unsigned long']],
    'NumberOfPfnReferences': [16, ['unsigned long']],
    'NumberOfSectionReferences': [12, ['unsigned long']],
    'NumberOfUserReferences': [28, ['unsigned long']],
    'Segment': [0, ['pointer', ['_SEGMENT']]],
    'WaitingForDeletion': [40, ['pointer', ['_EVENT_COUNTER']]],
    'u': [32, ['__unnamed_1224']],
   }],
   '_DBGKD_GET_VERSION64': [40, {
    'KernBase': [16, ['unsigned long long']],
    'MajorVersion': [0, ['unsigned short']],
    'MinorVersion': [2, ['unsigned short']],
    'PsLoadedModuleList': [24, ['unsigned long long']],
   }],
   '_DEVICE_OBJECT': [184, {
    'AttachedDevice': [16, ['pointer', ['_DEVICE_OBJECT']]],
    'DeviceType': [44, ['unsigned long']],
    'DriverObject': [8, ['pointer', ['_DRIVER_OBJECT']]],
    'NextDevice': [12, ['pointer', ['_DEVICE_OBJECT']]],
   }],
   '_DISPATCHER_HEADER': [16, {
    'SignalState': [4, ['long']],
    'Type': [0, ['unsigned char']],
   }],
   '_DRIVER_EXTENSION': [28, {
    'ServiceKeyName': [12, ['_UNICODE_STRING']],
   }],
   '_DRIVER_OBJECT': [168, {
    'DeviceObject': [4, ['pointer', ['_DEVICE_OBJECT']]],
    'DriverName': [28, ['_UNICODE_STRING']],
    'DriverSize': [16, ['unsigned long']],
    'DriverStart': [12, ['pointer', ['void']]],
    'DriverStartIo': [48, ['pointer', ['void']]],
    'MajorFunction': [56, ['array', 28, ['pointer', ['void']]]],
   }],
   '_DUAL': [220, {
    'Length': [0, ['unsigned long']],
    'Map': [4, ['pointer', ['_HMAP_DIRECTORY']]],
   }],
   '_EPROCESS': [608, {
    'ActiveProcessLinks': [136, ['_LIST_ENTRY']],
    'ActiveThreads': [416, ['unsigned long']],
    'AddressCreationLock': [240, ['_FAST_MUTEX']],
    'AddressSpaceInitialized': [584, ['BitField', {
     'end_bit': 12,
     'native_type': 'unsigned long',
     'start_bit': 10,
    }]],
    'AweInfo': [496, ['pointer', ['void']]],
    'BreakOnTermination': [584, ['BitField', {
     'end_bit': 14,
     'native_type': 'unsigned long',
     'start_bit': 13,
    }]],
    'CloneRoot': [292, ['pointer', ['void']]],
    'CommitCharge': [168, ['unsigned long']],
    'CommitChargeLimit': [488, ['unsigned long']],
    'CommitChargePeak': [492, ['unsigned long']],
    'Cookie': [600, ['unsigned long']],
    'CreateReported': [584, ['BitField', {
     'end_bit': 1,
     'native_type': 'unsigned long',
     'start_bit': 0,
    }]],
    'CreateTime': [112, ['_LARGE_INTEGER']],
    'DebugPort': [188, ['pointer', ['void']]],
    'DefaultHardErrorProcessing': [424, ['unsigned long']],
    'DeviceMap': [348, ['pointer', ['void']]],
    'ExceptionPort': [192, ['pointer', ['void']]],
    'ExitStatus': [588, ['long']],
    'ExitTime': [120, ['_LARGE_INTEGER']],
    'Filler': [360, ['unsigned long long']],
    'Flags': [584, ['unsigned long']],
    'ForkFailed': [584, ['BitField', {
     'end_bit': 9,
     'native_type': 'unsigned long',
     'start_bit': 8,
    }]],
    'ForkInProgress': [276, ['pointer', ['_ETHREAD']]],
    'GrantedAccess': [420, ['unsigned long']],
    'HardwareTrigger': [280, ['unsigned long']],
    'HasAddressSpace': [584, ['BitField', {
     'end_bit': 19,
     'native_type': 'unsigned long',
     'start_bit': 18,
    }]],
    'HasPhysicalVad': [584, ['BitField', {
     'end_bit': 10,
     'native_type': 'unsigned long',
     'start_bit': 9,
    }]],
    'HyperSpaceLock': [272, ['unsigned long']],
    'ImageFileName': [372, ['array', 16, ['unsigned char']]],
    'InheritedFromUniqueProcessId': [332, ['pointer', ['void']]],
    'InjectInpageErrors': [584, ['BitField', {
     'end_bit': 21,
     'native_type': 'unsigned long',
     'start_bit': 20,
    }]],
    'Job': [308, ['pointer', ['_EJOB']]],
    'JobLinks': [388, ['_LIST_ENTRY']],
    'JobStatus': [580, ['unsigned long']],
    'LastFaultCount': [568, ['unsigned long']],
    'LastThreadExitStatus': [428, ['long']],
    'LaunchPrefetched': [584, ['BitField', {
     'end_bit': 20,
     'native_type': 'unsigned long',
     'start_bit': 19,
    }]],
    'LdtInformation': [336, ['pointer', ['void']]],
    'LockedPagesList': [396, ['pointer', ['void']]],
    'ModifiedPageCount': [572, ['unsigned long']],
    'NextPageColor': [592, ['unsigned short']],
    'NoDebugInherit': [584, ['BitField', {
     'end_bit': 2,
     'native_type': 'unsigned long',
     'start_bit': 1,
    }]],
    'NumberOfLockedPages': [300, ['unsigned long']],
    'NumberOfPrivatePages': [296, ['unsigned long']],
    'NumberOfVads': [576, ['unsigned long']],
    'ObjectTable': [196, ['pointer', ['_HANDLE_TABLE']]],
    'OtherOperationCount': [456, ['_LARGE_INTEGER']],
    'OtherTransferCount': [480, ['_LARGE_INTEGER']],
    'OutswapEnabled': [584, ['BitField', {
     'end_bit': 7,
     'native_type': 'unsigned long',
     'start_bit': 6,
    }]],
    'Outswapped': [584, ['BitField', {
     'end_bit': 8,
     'native_type': 'unsigned long',
     'start_bit': 7,
    }]],
    'OverrideAddressSpace': [584, ['BitField', {
     'end_bit': 18,
     'native_type': 'unsigned long',
     'start_bit': 17,
    }]],
    'PaeTop': [412, ['pointer', ['void']]],
    'PageDirectoryPte': [360, ['_HARDWARE_PTE']],
    'Pcb': [0, ['_KPROCESS']],
    'PeakVirtualSize': [172, ['unsigned long']],
    'Peb': [432, ['pointer', ['_PEB']]],
    'PhysicalVadList': [352, ['_LIST_ENTRY']],
    'PrefetchTrace': [436, ['_EX_FAST_REF']],
    'PriorityClass': [596, ['unsigned char']],
    'ProcessDelete': [584, ['BitField', {
     'end_bit': 4,
     'native_type': 'unsigned long',
     'start_bit': 3,
    }]],
    'ProcessExiting': [584, ['BitField', {
     'end_bit': 3,
     'native_type': 'unsigned long',
     'start_bit': 2,
    }]],
    'ProcessInSession': [584, ['BitField', {
     'end_bit': 17,
     'native_type': 'unsigned long',
     'start_bit': 16,
    }]],
    'ProcessLock': [108, ['_EX_PUSH_LOCK']],
    'QuotaBlock': [320, ['pointer', ['_EPROCESS_QUOTA_BLOCK']]],
    'QuotaPeak': [156, ['array', 3, ['unsigned long']]],
    'QuotaUsage': [144, ['array', 3, ['unsigned long']]],
    'ReadOperationCount': [440, ['_LARGE_INTEGER']],
    'ReadTransferCount': [464, ['_LARGE_INTEGER']],
    'RundownProtect': [128, ['_EX_RUNDOWN_REF']],
    'SeAuditProcessCreationInfo': [500, ['_SE_AUDIT_PROCESS_CREATION_INFO']],
    'SectionBaseAddress': [316, ['pointer', ['void']]],
    'SectionObject': [312, ['pointer', ['void']]],
    'SecurityPort': [408, ['pointer', ['void']]],
    'Session': [368, ['pointer', ['void']]],
    'SessionCreationUnderway': [584, ['BitField', {
     'end_bit': 15,
     'native_type': 'unsigned long',
     'start_bit': 14,
    }]],
    'SessionProcessLinks': [180, ['_LIST_ENTRY']],
    'SetTimerResolution': [584, ['BitField', {
     'end_bit': 13,
     'native_type': 'unsigned long',
     'start_bit': 12,
    }]],
    'SubSystemMajorVersion': [595, ['unsigned char']],
    'SubSystemMinorVersion': [594, ['unsigned char']],
    'SubSystemVersion': [594, ['unsigned short']],
    'ThreadListHead': [400, ['_LIST_ENTRY']],
    'Token': [200, ['_EX_FAST_REF']],
    'UniqueProcessId': [132, ['pointer', ['void']]],
    'Unused': [584, ['BitField', {
     'end_bit': 30,
     'native_type': 'unsigned long',
     'start_bit': 25,
    }]],
    'Unused1': [584, ['BitField', {
     'end_bit': 31,
     'native_type': 'unsigned long',
     'start_bit': 30,
    }]],
    'Unused2': [584, ['BitField', {
     'end_bit': 32,
     'native_type': 'unsigned long',
     'start_bit': 31,
    }]],
    'Unused3': [584, ['BitField', {
     'end_bit': 23,
     'native_type': 'unsigned long',
     'start_bit': 22,
    }]],
    'Unused4': [584, ['BitField', {
     'end_bit': 24,
     'native_type': 'unsigned long',
     'start_bit': 23,
    }]],
    'VadFreeHint': [340, ['pointer', ['void']]],
    'VadHint': [288, ['pointer', ['void']]],
    'VadRoot': [284, ['pointer', ['void']]],
    'VdmAllowed': [584, ['BitField', {
     'end_bit': 25,
     'native_type': 'unsigned long',
     'start_bit': 24,
    }]],
    'VdmObjects': [344, ['pointer', ['void']]],
    'VirtualSize': [176, ['unsigned long']],
    'Vm': [504, ['_MMSUPPORT']],
    'VmDeleted': [584, ['BitField', {
     'end_bit': 6,
     'native_type': 'unsigned long',
     'start_bit': 5,
    }]],
    'VmTopDown': [584, ['BitField', {
     'end_bit': 22,
     'native_type': 'unsigned long',
     'start_bit': 21,
    }]],
    'Win32Process': [304, ['pointer', ['void']]],
    'Win32WindowStation': [328, ['pointer', ['void']]],
    'WorkingSetAcquiredUnsafe': [597, ['unsigned char']],
    'WorkingSetLock': [204, ['_FAST_MUTEX']],
    'WorkingSetPage': [236, ['unsigned long']],
    'WorkingSetWatch': [324, ['pointer', ['_PAGEFAULT_HISTORY']]],
    'Wow64SplitPages': [584, ['BitField', {
     'end_bit': 5,
     'native_type': 'unsigned long',
     'start_bit': 4,
    }]],
    'WriteOperationCount': [448, ['_LARGE_INTEGER']],
    'WriteTransferCount': [472, ['_LARGE_INTEGER']],
    'WriteWatch': [584, ['BitField', {
     'end_bit': 16,
     'native_type': 'unsigned long',
     'start_bit': 15,
    }]],
   }],
   '_ETHREAD': [600, {
    'Cid': [492, ['_CLIENT_ID']],
    'CreateTime': [448, ['_LARGE_INTEGER']],
    'ExitTime': [456, ['_LARGE_INTEGER']],
    'KeyedWaitSemaphore': [500, ['_KSEMAPHORE']],
    'StartAddress': [548, ['pointer', ['void']]],
    'Tcb': [0, ['_KTHREAD']],
    'ThreadsProcess': [544, ['pointer', ['_EPROCESS']]],
   }],
   '_EX_FAST_REF': [4, {
    'Object': [0, ['pointer', ['void']]],
   }],
   '_EX_PUSH_LOCK': [4, {
   }],
   '_EX_RUNDOWN_REF': [4, {
   }],
   '_FAST_MUTEX': [32, {
   }],
   '_FILE_OBJECT': [112, {
    'DeleteAccess': [40, ['unsigned char']],
    'DeviceObject': [4, ['pointer', ['_DEVICE_OBJECT']]],
    'FileName': [48, ['_UNICODE_STRING']],
    'ReadAccess': [38, ['unsigned char']],
    'SharedDelete': [43, ['unsigned char']],
    'SharedRead': [41, ['unsigned char']],
    'SharedWrite': [42, ['unsigned char']],
    'WriteAccess': [39, ['unsigned char']],
   }],
   '_HANDLE_TABLE': [68, {
    'HandleCount': [60, ['long']],
    'HandleTableList': [28, ['_LIST_ENTRY']],
    'TableCode': [0, ['unsigned long']],
   }],
   '_HANDLE_TABLE_ENTRY': [8, {
    'GrantedAccess': [4, ['unsigned long']],
    'Object': [0, ['pointer', ['void']]],
   }],
   '_HARDWARE_PTE': [4, {
   }],
   '_HHIVE': [528, {
    'BaseBlock': [36, ['pointer', ['_HBASE_BLOCK']]],
    'Flat': [64, ['unsigned char']],
    'Signature': [0, ['unsigned long']],
    'Storage': [88, ['array', 2, ['_DUAL']]],
   }],
   '_HMAP_DIRECTORY': [4096, {
    'Directory': [0, ['array', 1024, ['pointer', ['_HMAP_TABLE']]]],
   }],
   '_HMAP_ENTRY': [16, {
    'BlockAddress': [0, ['unsigned long']],
   }],
   '_HMAP_TABLE': [8192, {
    'Table': [0, ['array', 512, ['_HMAP_ENTRY']]],
   }],
   '_IMAGE_DATA_DIRECTORY': [8, {
    'Size': [4, ['unsigned long']],
    'VirtualAddress': [0, ['unsigned long']],
   }],
   '_IMAGE_DOS_HEADER': [64, {
    'e_lfanew': [60, ['long']],
    'e_magic': [0, ['unsigned short']],
   }],
   '_IMAGE_NT_HEADERS': [248, {
    'OptionalHeader': [24, ['_IMAGE_OPTIONAL_HEADER']],
    'Signature': [0, ['unsigned long']],
   }],
   '_IMAGE_OPTIONAL_HEADER': [224, {
    'DataDirectory': [96, ['array', 16, ['_IMAGE_DATA_DIRECTORY']]],
    'Magic': [0, ['unsigned short']],
    'MajorOperatingSystemVersion': [40, ['unsigned short']],
    'MinorOperatingSystemVersion': [42, ['unsigned short']],
    'SizeOfImage': [56, ['unsigned long']],
   }],
   '_KAPC_STATE': [24, {
    'Process': [16, ['pointer', ['_KPROCESS']]],
   }],
   '_KDPC': [32, {
    'DeferredRoutine': [12, ['pointer', ['void']]],
   }],
   '_KMUTANT': [32, {
    'Header': [0, ['_DISPATCHER_HEADER']],
    'OwnerThread': [24, ['pointer', ['_KTHREAD']]],
   }],
   '_KPCR': [3440, {
    'Prcb': [32, ['pointer', ['_KPRCB']]],
    'PrcbData': [288, ['_KPRCB']],
   }],
   '_KPRCB': [3152, {
    'Number': [16, ['unsigned char']],
   }],
   '_KPROCESS': [108, {
    'DirectoryTableBase': [24, ['array', 2, ['unsigned long']]],
   }],
   '_KSEMAPHORE': [20, {
    'Header': [0, ['_DISPATCHER_HEADER']],
   }],
   '_KTHREAD': [448, {
    'ApcState': [52, ['_KAPC_STATE']],
    'SuspendSemaphore': [412, ['_KSEMAPHORE']],
   }],
   '_KTIMER': [40, {
    'Dpc': [32, ['pointer', ['_KDPC']]],
    'DueTime': [16, ['_ULARGE_INTEGER']],
    'Header': [0, ['_DISPATCHER_HEADER']],
    'Period': [36, ['long']],
    'TimerListEntry': [24, ['_LIST_ENTRY']],
   }],
   '_LARGE_INTEGER': [8, {
   }],
   '_LDR_DATA_TABLE_ENTRY': [80, {
    'BaseDllName': [44, ['_UNICODE_STRING']],
    'DllBase': [24, ['pointer', ['void']]],
    'FullDllName': [36, ['_UNICODE_STRING']],
    'InInitializationOrderLinks': [16, ['_LIST_ENTRY']],
    'InLoadOrderLinks': [0, ['_LIST_ENTRY']],
    'InMemoryOrderLinks': [8, ['_LIST_ENTRY']],
    'SizeOfImage': [32, ['unsigned long']],
   }],
   '_LIST_ENTRY': [8, {
    'Blink': [4, ['pointer', ['_LIST_ENTRY']]],
    'Flink': [0, ['pointer', ['_LIST_ENTRY']]],
   }],
   '_MMPFN': [24, {
    'PteAddress': [4, ['pointer', ['_MMPTE']]],
    'u1': [0, ['__unnamed_179d']],
    'u3': [12, ['__unnamed_17a4']],
    'u4': [20, ['__unnamed_17aa']],
   }],
   '_MMPFNENTRY': [4, {
    'PageLocation': [0, ['BitField', {
     'end_bit': 11,
     'native_type': 'unsigned long',
     'start_bit': 8,
    }]],
   }],
   '_MMSECTION_FLAGS': [4, {
    'Accessed': [0, ['BitField', {
     'end_bit': 28,
     'native_type': 'unsigned long',
     'start_bit': 27,
    }]],
    'Based': [0, ['BitField', {
     'end_bit': 7,
     'native_type': 'unsigned long',
     'start_bit': 6,
    }]],
    'BeingCreated': [0, ['BitField', {
     'end_bit': 2,
     'native_type': 'unsigned long',
     'start_bit': 1,
    }]],
    'BeingDeleted': [0, ['BitField', {
     'end_bit': 1,
     'native_type': 'unsigned long',
     'start_bit': 0,
    }]],
    'BeingPurged': [0, ['BitField', {
     'end_bit': 3,
     'native_type': 'unsigned long',
     'start_bit': 2,
    }]],
    'CollidedFlush': [0, ['BitField', {
     'end_bit': 23,
     'native_type': 'unsigned long',
     'start_bit': 22,
    }]],
    'Commit': [0, ['BitField', {
     'end_bit': 14,
     'native_type': 'unsigned long',
     'start_bit': 13,
    }]],
    'CopyOnWrite': [0, ['BitField', {
     'end_bit': 12,
     'native_type': 'unsigned long',
     'start_bit': 11,
    }]],
    'DebugSymbolsLoaded': [0, ['BitField', {
     'end_bit': 21,
     'native_type': 'unsigned long',
     'start_bit': 20,
    }]],
    'DeleteOnClose': [0, ['BitField', {
     'end_bit': 19,
     'native_type': 'unsigned long',
     'start_bit': 18,
    }]],
    'FailAllIo': [0, ['BitField', {
     'end_bit': 5,
     'native_type': 'unsigned long',
     'start_bit': 4,
    }]],
    'File': [0, ['BitField', {
     'end_bit': 8,
     'native_type': 'unsigned long',
     'start_bit': 7,
    }]],
    'FilePointerNull': [0, ['BitField', {
     'end_bit': 20,
     'native_type': 'unsigned long',
     'start_bit': 19,
    }]],
    'FloppyMedia': [0, ['BitField', {
     'end_bit': 15,
     'native_type': 'unsigned long',
     'start_bit': 14,
    }]],
    'GlobalMemory': [0, ['BitField', {
     'end_bit': 18,
     'native_type': 'unsigned long',
     'start_bit': 17,
    }]],
    'GlobalOnlyPerSession': [0, ['BitField', {
     'end_bit': 29,
     'native_type': 'unsigned long',
     'start_bit': 28,
    }]],
    'HadUserReference': [0, ['BitField', {
     'end_bit': 25,
     'native_type': 'unsigned long',
     'start_bit': 24,
    }]],
    'Image': [0, ['BitField', {
     'end_bit': 6,
     'native_type': 'unsigned long',
     'start_bit': 5,
    }]],
    'ImageMappedInSystemSpace': [0, ['BitField', {
     'end_bit': 26,
     'native_type': 'unsigned long',
     'start_bit': 25,
    }]],
    'Networked': [0, ['BitField', {
     'end_bit': 9,
     'native_type': 'unsigned long',
     'start_bit': 8,
    }]],
    'NoCache': [0, ['BitField', {
     'end_bit': 10,
     'native_type': 'unsigned long',
     'start_bit': 9,
    }]],
    'NoChange': [0, ['BitField', {
     'end_bit': 24,
     'native_type': 'unsigned long',
     'start_bit': 23,
    }]],
    'NoModifiedWriting': [0, ['BitField', {
     'end_bit': 4,
     'native_type': 'unsigned long',
     'start_bit': 3,
    }]],
    'PhysicalMemory': [0, ['BitField', {
     'end_bit': 11,
     'native_type': 'unsigned long',
     'start_bit': 10,
    }]],
    'Reserve': [0, ['BitField', {
     'end_bit': 13,
     'native_type': 'unsigned long',
     'start_bit': 12,
    }]],
    'Rom': [0, ['BitField', {
     'end_bit': 30,
     'native_type': 'unsigned long',
     'start_bit': 29,
    }]],
    'SetMappedFileIoComplete': [0, ['BitField', {
     'end_bit': 22,
     'native_type': 'unsigned long',
     'start_bit': 21,
    }]],
    'UserReference': [0, ['BitField', {
     'end_bit': 17,
     'native_type': 'unsigned long',
     'start_bit': 16,
    }]],
    'UserWritable': [0, ['BitField', {
     'end_bit': 27,
     'native_type': 'unsigned long',
     'start_bit': 26,
    }]],
    'WasPurged': [0, ['BitField', {
     'end_bit': 16,
     'native_type': 'unsigned long',
     'start_bit': 15,
    }]],
    'filler': [0, ['BitField', {
     'end_bit': 32,
     'native_type': 'unsigned long',
     'start_bit': 30,
    }]],
   }],
   '_MMSUPPORT': [64, {
   }],
   '_MMVAD': [40, {
    'ControlArea': [24, ['pointer', ['_CONTROL_AREA']]],
    'EndingVpn': [4, ['unsigned long']],
    'FirstPrototypePte': [28, ['pointer', ['_MMPTE']]],
    'LastContiguousPte': [32, ['pointer', ['_MMPTE']]],
    'LeftChild': [12, ['pointer', ['_MMVAD']]],
    'RightChild': [16, ['pointer', ['_MMVAD']]],
    'StartingVpn': [0, ['unsigned long']],
    'u': [20, ['__unnamed_144c']],
    'u2': [36, ['__unnamed_144f']],
   }],
   '_MMVAD_FLAGS': [4, {
    'CommitCharge': [0, ['BitField', {
     'end_bit': 19,
     'native_type': 'unsigned long',
     'start_bit': 0,
    }]],
    'ImageMap': [0, ['BitField', {
     'end_bit': 21,
     'native_type': 'unsigned long',
     'start_bit': 20,
    }]],
    'LargePages': [0, ['BitField', {
     'end_bit': 30,
     'native_type': 'unsigned long',
     'start_bit': 29,
    }]],
    'MemCommit': [0, ['BitField', {
     'end_bit': 31,
     'native_type': 'unsigned long',
     'start_bit': 30,
    }]],
    'NoChange': [0, ['BitField', {
     'end_bit': 23,
     'native_type': 'unsigned long',
     'start_bit': 22,
    }]],
    'PhysicalMapping': [0, ['BitField', {
     'end_bit': 20,
     'native_type': 'unsigned long',
     'start_bit': 19,
    }]],
    'PrivateMemory': [0, ['BitField', {
     'end_bit': 32,
     'native_type': 'unsigned long',
     'start_bit': 31,
    }]],
    'Protection': [0, ['BitField', {
     'end_bit': 29,
     'native_type': 'unsigned long',
     'start_bit': 24,
    }]],
    'UserPhysicalPages': [0, ['BitField', {
     'end_bit': 22,
     'native_type': 'unsigned long',
     'start_bit': 21,
    }]],
    'WriteWatch': [0, ['BitField', {
     'end_bit': 24,
     'native_type': 'unsigned long',
     'start_bit': 23,
    }]],
   }],
   '_MMVAD_FLAGS2': [4, {
    'CopyOnWrite': [0, ['BitField', {
     'end_bit': 32,
     'native_type': 'unsigned long',
     'start_bit': 31,
    }]],
    'ExtendableFile': [0, ['BitField', {
     'end_bit': 30,
     'native_type': 'unsigned long',
     'start_bit': 29,
    }]],
    'FileOffset': [0, ['BitField', {
     'end_bit': 24,
     'native_type': 'unsigned long',
     'start_bit': 0,
    }]],
    'Inherit': [0, ['BitField', {
     'end_bit': 31,
     'native_type': 'unsigned long',
     'start_bit': 30,
    }]],
    'LongVad': [0, ['BitField', {
     'end_bit': 29,
     'native_type': 'unsigned long',
     'start_bit': 28,
    }]],
    'MultipleSecured': [0, ['BitField', {
     'end_bit': 27,
     'native_type': 'unsigned long',
     'start_bit': 26,
    }]],
    'OneSecured': [0, ['BitField', {
     'end_bit': 26,
     'native_type': 'unsigned long',
     'start_bit': 25,
    }]],
    'ReadOnly': [0, ['BitField', {
     'end_bit': 28,
     'native_type': 'unsigned long',
     'start_bit': 27,
    }]],
    'SecNoChange': [0, ['BitField', {
     'end_bit': 25,
     'native_type': 'unsigned long',
     'start_bit': 24,
    }]],
   }],
   '_MMVAD_LONG': [52, {
    'ControlArea': [24, ['pointer', ['_CONTROL_AREA']]],
    'EndingVpn': [4, ['unsigned long']],
    'FirstPrototypePte': [28, ['pointer', ['_MMPTE']]],
    'LastContiguousPte': [32, ['pointer', ['_MMPTE']]],
    'LeftChild': [12, ['pointer', ['_MMVAD']]],
    'RightChild': [16, ['pointer', ['_MMVAD']]],
    'StartingVpn': [0, ['unsigned long']],
    'u': [20, ['__unnamed_144c']],
    'u2': [36, ['__unnamed_144f']],
   }],
   '_MMVAD_SHORT': [24, {
    'EndingVpn': [4, ['unsigned long']],
    'LeftChild': [12, ['pointer', ['_MMVAD']]],
    'RightChild': [16, ['pointer', ['_MMVAD']]],
    'StartingVpn': [0, ['unsigned long']],
    'u': [20, ['__unnamed_144c']],
   }],
   '_MM_SESSION_SPACE': [4728, {
    'ImageList': [156, ['_LIST_ENTRY']],
    'PagedPoolEnd': [104, ['pointer', ['void']]],
    'PagedPoolStart': [100, ['pointer', ['void']]],
    'ProcessList': [20, ['_LIST_ENTRY']],
    'SessionId': [8, ['unsigned long']],
   }],
   '_OBJECT_HEADER': [32, {
    'Body': [24, ['_QUAD']],
    'HandleCount': [4, ['long']],
    'NameInfoOffset': [12, ['unsigned char']],
    'PointerCount': [0, ['long']],
    'Type': [8, ['pointer', ['_OBJECT_TYPE']]],
   }],
   '_OBJECT_HEADER_NAME_INFO': [16, {
    'Name': [4, ['_UNICODE_STRING']],
   }],
   '_OBJECT_SYMBOLIC_LINK': [32, {
    'CreationTime': [0, ['_LARGE_INTEGER']],
    'LinkTarget': [8, ['_UNICODE_STRING']],
   }],
   '_OBJECT_TYPE': [400, {
    'Name': [64, ['_UNICODE_STRING']],
   }],
   '_PEB': [528, {
    'CSDVersion': [496, ['_UNICODE_STRING']],
    'ImageBaseAddress': [8, ['pointer', ['void']]],
    'Ldr': [12, ['pointer', ['_PEB_LDR_DATA']]],
    'ProcessParameters': [16, ['pointer', ['_RTL_USER_PROCESS_PARAMETERS']]],
   }],
   '_PEB_LDR_DATA': [40, {
    'InInitializationOrderModuleList': [28, ['_LIST_ENTRY']],
    'InLoadOrderModuleList': [12, ['_LIST_ENTRY']],
    'InMemoryOrderModuleList': [20, ['_LIST_ENTRY']],
   }],
   '_POOL_HEADER': [8, {
    'BlockSize': [2, ['BitField', {
     'end_bit': 9,
     'native_type': 'unsigned short',
     'start_bit': 0,
    }]],
    'PoolIndex': [0, ['BitField', {
     'end_bit': 16,
     'native_type': 'unsigned short',
     'start_bit': 9,
    }]],
    'PoolTag': [4, ['unsigned long']],
    'PoolType': [2, ['BitField', {
     'end_bit': 16,
     'native_type': 'unsigned short',
     'start_bit': 9,
    }]],
   }],
   '_QUAD': [8, {
   }],
   '_RTL_ATOM_TABLE': [68, {
    'Buckets': [64, ['array', 1, ['pointer', ['_RTL_ATOM_TABLE_ENTRY']]]],
    'Signature': [0, ['unsigned long']],
   }],
   '_RTL_ATOM_TABLE_ENTRY': [16, {
    'Atom': [6, ['unsigned short']],
    'Flags': [10, ['unsigned char']],
    'HandleIndex': [4, ['unsigned short']],
    'HashLink': [0, ['pointer', ['_RTL_ATOM_TABLE_ENTRY']]],
    'Name': [12, ['array', 1, ['unsigned short']]],
    'NameLength': [11, ['unsigned char']],
    'ReferenceCount': [8, ['unsigned short']],
   }],
   '_RTL_USER_PROCESS_PARAMETERS': [656, {
    'CommandLine': [64, ['_UNICODE_STRING']],
    'Environment': [72, ['pointer', ['void']]],
   }],
   '_SE_AUDIT_PROCESS_CREATION_INFO': [4, {
   }],
   '_SID': [12, {
    'IdentifierAuthority': [2, ['_SID_IDENTIFIER_AUTHORITY']],
    'Revision': [0, ['unsigned char']],
    'SubAuthority': [8, ['array', 1, ['unsigned long']]],
    'SubAuthorityCount': [1, ['unsigned char']],
   }],
   '_SID_AND_ATTRIBUTES': [8, {
    'Sid': [0, ['pointer', ['void']]],
   }],
   '_SID_IDENTIFIER_AUTHORITY': [6, {
    'Value': [0, ['array', 6, ['unsigned char']]],
   }],
   '_TOKEN': [168, {
    'UserAndGroupCount': [76, ['unsigned long']],
    'UserAndGroups': [104, ['pointer', ['_SID_AND_ATTRIBUTES']]],
   }],
   '_ULARGE_INTEGER': [8, {
    'QuadPart': [0, ['unsigned long long']],
   }],
   '_UNICODE_STRING': [8, {
    'Buffer': [4, ['pointer', ['unsigned short']]],
    'Length': [0, ['unsigned short']],
   }],
   '__unnamed_1224': [4, {
    'Flags': [0, ['_MMSECTION_FLAGS']],
   }],
   '__unnamed_144c': [4, {
    'VadFlags': [0, ['_MMVAD_FLAGS']],
   }],
   '__unnamed_144f': [4, {
    'VadFlags2': [0, ['_MMVAD_FLAGS2']],
   }],
   '__unnamed_179d': [4, {
    'Flink': [0, ['unsigned long']],
   }],
   '__unnamed_17a4': [4, {
    'e1': [0, ['_MMPFNENTRY']],
   }],
   '__unnamed_17aa': [4, {
    'PteFrame': [0, ['BitField', {
     'end_bit': 26,
     'native_type': 'unsigned long',
     'start_bit': 0,
    }]],
   }],
  },
 },
 'WinXPSP3x86': {
  'metadata': {
   'Constants': 'Constants.json',
   'ProfileClass': 'WinXPSP3x86',
   'VTypes': 'vtypes.json',
  },
  'vtypes.json': {
   'LIST_ENTRY32': [8, {
    'Blink': [4, ['unsigned long']],
    'Flink': [0, ['unsigned long']],
   }],
   'LIST_ENTRY64': [16, {
   }],
   '_CONTROL_AREA': [48, {
    'FilePointer': [36, ['pointer', ['_FILE_OBJECT']]],
   }],
   '_EPROCESS': [608, {
    'ActiveProcessLinks': [136, ['_LIST_ENTRY']],
    'ActiveThreads': [416, ['unsigned long']],
    'CreateTime': [112, ['_LARGE_INTEGER']],
    'ExitTime': [120, ['_LARGE_INTEGER']],
    'ImageFileName': [372, ['array', 16, ['unsigned char']]],
    'InheritedFromUniqueProcessId': [332, ['pointer', ['void']]],
    'ObjectTable': [196, ['pointer', ['_HANDLE_TABLE']]],
    'Pcb': [0, ['_KPROCESS']],
    'Session': [368, ['pointer', ['void']]],
    'ThreadListHead': [400, ['_LIST_ENTRY']],
    'UniqueProcessId': [132, ['pointer', ['void']]],
    'VadRoot': [284, ['pointer', ['void']]],
   }],
   '_FILE_OBJECT': [112, {
    'FileName': [48, ['_UNICODE_STRING']],
   }],
   '_HANDLE_TABLE': [68, {
    'HandleCount': [60, ['long']],
   }],
   '_KPROCESS': [108, {
    'DirectoryTableBase': [24, ['array', 2, ['unsigned long']]],
   }],
   '_LIST_ENTRY': [8, {
    'Blink': [4, ['pointer', ['_LIST_ENTRY']]],
    'Flink': [0, ['pointer', ['_LIST_ENTRY']]],
   }],
   '_MMVAD': [40, {
    'ControlArea': [24, ['pointer', ['_CONTROL_AREA']]],
    'EndingVpn': [4, ['unsigned long']],
    'LeftChild': [12, ['pointer', ['_MMVAD']]],
    'RightChild': [16, ['pointer', ['_MMVAD']]],
    'StartingVpn': [0, ['unsigned long']],
    'u': [20, ['__unnamed_1492']],
   }],
   '_MMVAD_FLAGS': [4, {
    'CommitCharge': [0, ['BitField', {
     'end_bit': 19,
     'native_type': 'unsigned long',
     'start_bit': 0,
    }]],
    'PrivateMemory': [0, ['BitField', {
     'end_bit': 32,
     'native_type': 'unsigned long',
     'start_bit': 31,
    }]],
    'Protection': [0, ['BitField', {
     'end_bit': 29,
     'native_type': 'unsigned long',
     'start_bit': 24,
    }]],
   }],
   '_MMVAD_LONG': [52, {
    'ControlArea': [24, ['pointer', ['_CONTROL_AREA']]],
    'EndingVpn': [4, ['unsigned long']],
    'StartingVpn': [0, ['unsigned long']],
    'u': [20, ['__unnamed_1492']],
   }],
   '_MMVAD_SHORT': [24, {
    'EndingVpn': [4, ['unsigned long']],
    'StartingVpn': [0, ['unsigned long']],
    'u': [20, ['__unnamed_1492']],
   }],
   '_MM_SESSION_SPACE': [4728, {
    'SessionId': [8, ['unsigned long']],
   }],
   '_UNICODE_STRING': [8, {
    'Buffer': [4, ['pointer', ['unsigned short']]],
    'Length': [0, ['unsigned short']],
   }],
   '__unnamed_1492': [4, {
    'VadFlags': [0, ['_MMVAD_FLAGS']],
   }],
  },
 },
}




# Rekall Memory Forensics
#
# Copyright 2013 Google Inc. All Rights Reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or (at
# your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#

import rekall.obj as obj



class _KDDEBUGGER_DATA64(obj.Struct):
    """A class for KDBG"""

    def is_valid(self):
        """Returns true if the kdbg_object appears valid"""
        # Check the OwnerTag is in fact the string KDBG
        return (super(_KDDEBUGGER_DATA64, self).is_valid() and
                self.Header.OwnerTag == 0x4742444B)

    @property
    def ServicePack(self):
        """Get the service pack number. This is something
        like 0x100 for SP1, 0x200 for SP2 etc.
        """
        csdresult = self.obj_profile.Object(
            "unsigned long", offset = self.CmNtCSDVersion, vm = self.obj_vm)
        return (csdresult >> 8) & 0xffffffff

    def dbgkd_version64(self):
        """Scan backwards from the base of KDBG to find the
        _DBGKD_GET_VERSION64. We have a winner when kernel
        base addresses and process list head match."""

        # Account for address masking differences in x86 and x64
        memory_model = self.obj_profile.metadata('memory_model', '32bit')

        dbgkd_off = self.obj_offset & 0xFFFFFFFFFFFFF000
        dbgkd_end = dbgkd_off + 0x1000
        dbgkd_size = self.obj_profile.get_obj_size("_DBGKD_GET_VERSION64")

        while dbgkd_off <= (dbgkd_end - dbgkd_size):

            dbgkd = self.obj_profile.Object(
                "_DBGKD_GET_VERSION64", offset = dbgkd_off, vm = self.obj_vm)

            if memory_model == "32bit":
                KernBase = dbgkd.KernBase & 0xFFFFFFFF
                PsLoadedModuleList = dbgkd.PsLoadedModuleList & 0xFFFFFFFF
            else:
                KernBase = dbgkd.KernBase
                PsLoadedModuleList = dbgkd.PsLoadedModuleList

            if ((KernBase == self.KernBase) and (PsLoadedModuleList == self.PsLoadedModuleList)):
                return dbgkd

            dbgkd_off += 1

        return obj.NoneObject("Cannot find _DBGKD_GET_VERSION64")

    def kpcrs(self):
        """Generator for KPCRs referenced by this KDBG.

        These are returned in the order in which the
        processors were registered.
        """

        if self.obj_profile.metadata('memory_model') == '32bit':
            prcb_member = "PrcbData"
        else:
            prcb_member = "Prcb"

        cpu_array = self.KiProcessorBlock.dereference()

        for p in cpu_array:

            # A null pointer indicates the end of the CPU list. Since
            # the 0 page is not valid in kernel AS, this single check
            # should match both NoneObject and null pointers.
            if not p:
                break

            kpcrb = p.dereference_as("_KPRCB")

            yield self.obj_profile.Object(
                "_KPCR",
                offset=(kpcrb.obj_offset -
                        self.obj_profile.get_obj_offset("_KPCR", prcb_member)),
                vm = self.obj_vm)


kdbg_overlay = {
    '_KDDEBUGGER_DATA64': [ None, {
            'NtBuildLab': [ None, ['pointer', ['String', dict(length = 32)]]],
            'KiProcessorBlock': [ None, [
                    'Pointer', {
                        'target': 'Array',
                        'target_args': {
                            'count': lambda x: 32 + 32 * int(
                                x.obj_profile.metadata("memory_model") == "64bit"),
                            "target": "Pointer",
                            "target_args": dict(target="_KPRCB"),
                            }
                        }]],

            'MmPhysicalMemoryBlock': [None, [
                    'Pointer', dict(
                        target='Pointer',
                        target_args=dict(
                            target='_PHYSICAL_MEMORY_DESCRIPTOR'
                            )
                        )
                    ]],
            'PsActiveProcessHead': [None, [
                    'Pointer', dict(target='LIST_ENTRY64'),
                    ]],
            }],
    }


kdbg_vtypes = {
'_DBGKD_DEBUG_DATA_HEADER64' : [  0x18, {
  'List' : [ 0x0, ['LIST_ENTRY64']],
  'OwnerTag' : [ 0x10, ['String', dict(length=4)]],
  'Size' : [ 0x14, ['unsigned long']],
} ],

'_KDDEBUGGER_DATA64' : [  0x340, {
  'Header' : [ 0x0, ['_DBGKD_DEBUG_DATA_HEADER64']],
  'KernBase' : [ 0x18, ['unsigned long long']],
  'BreakpointWithStatus' : [ 0x20, ['unsigned long long']],
  'SavedContext' : [ 0x28, ['unsigned long long']],
  'ThCallbackStack' : [ 0x30, ['unsigned short']],
  'NextCallback' : [ 0x32, ['unsigned short']],
  'FramePointer' : [ 0x34, ['unsigned short']],
  'KiCallUserMode' : [ 0x38, ['unsigned long long']],
  'KeUserCallbackDispatcher' : [ 0x40, ['unsigned long long']],
  'PsLoadedModuleList' : [ 0x48, ['unsigned long long']],
  'PsActiveProcessHead' : [ 0x50, ['unsigned long long']],
  'PspCidTable' : [ 0x58, ['unsigned long long']],
  'ExpSystemResourcesList' : [ 0x60, ['unsigned long long']],
  'ExpPagedPoolDescriptor' : [ 0x68, ['unsigned long long']],
  'ExpNumberOfPagedPools' : [ 0x70, ['unsigned long long']],
  'KeTimeIncrement' : [ 0x78, ['unsigned long long']],
  'KeBugCheckCallbackListHead' : [ 0x80, ['unsigned long long']],
  'KiBugcheckData' : [ 0x88, ['unsigned long long']],
  'IopErrorLogListHead' : [ 0x90, ['unsigned long long']],
  'ObpRootDirectoryObject' : [ 0x98, ['unsigned long long']],
  'ObpTypeObjectType' : [ 0xa0, ['unsigned long long']],
  'MmSystemCacheStart' : [ 0xa8, ['unsigned long long']],
  'MmSystemCacheEnd' : [ 0xb0, ['unsigned long long']],
  'MmSystemCacheWs' : [ 0xb8, ['unsigned long long']],
  'MmPfnDatabase' : [ 0xc0, ['unsigned long long']],
  'MmSystemPtesStart' : [ 0xc8, ['unsigned long long']],
  'MmSystemPtesEnd' : [ 0xd0, ['unsigned long long']],
  'MmSubsectionBase' : [ 0xd8, ['unsigned long long']],
  'MmNumberOfPagingFiles' : [ 0xe0, ['unsigned long long']],
  'MmLowestPhysicalPage' : [ 0xe8, ['unsigned long long']],
  'MmHighestPhysicalPage' : [ 0xf0, ['unsigned long long']],
  'MmNumberOfPhysicalPages' : [ 0xf8, ['unsigned long long']],
  'MmMaximumNonPagedPoolInBytes' : [ 0x100, ['unsigned long long']],
  'MmNonPagedSystemStart' : [ 0x108, ['unsigned long long']],
  'MmNonPagedPoolStart' : [ 0x110, ['unsigned long long']],
  'MmNonPagedPoolEnd' : [ 0x118, ['unsigned long long']],
  'MmPagedPoolStart' : [ 0x120, ['unsigned long long']],
  'MmPagedPoolEnd' : [ 0x128, ['unsigned long long']],
  'MmPagedPoolInformation' : [ 0x130, ['unsigned long long']],
  'MmPageSize' : [ 0x138, ['unsigned long long']],
  'MmSizeOfPagedPoolInBytes' : [ 0x140, ['unsigned long long']],
  'MmTotalCommitLimit' : [ 0x148, ['unsigned long long']],
  'MmTotalCommittedPages' : [ 0x150, ['unsigned long long']],
  'MmSharedCommit' : [ 0x158, ['unsigned long long']],
  'MmDriverCommit' : [ 0x160, ['unsigned long long']],
  'MmProcessCommit' : [ 0x168, ['unsigned long long']],
  'MmPagedPoolCommit' : [ 0x170, ['unsigned long long']],
  'MmExtendedCommit' : [ 0x178, ['unsigned long long']],
  'MmZeroedPageListHead' : [ 0x180, ['unsigned long long']],
  'MmFreePageListHead' : [ 0x188, ['unsigned long long']],
  'MmStandbyPageListHead' : [ 0x190, ['unsigned long long']],
  'MmModifiedPageListHead' : [ 0x198, ['unsigned long long']],
  'MmModifiedNoWritePageListHead' : [ 0x1a0, ['unsigned long long']],
  'MmAvailablePages' : [ 0x1a8, ['unsigned long long']],
  'MmResidentAvailablePages' : [ 0x1b0, ['unsigned long long']],
  'PoolTrackTable' : [ 0x1b8, ['unsigned long long']],
  'NonPagedPoolDescriptor' : [ 0x1c0, ['unsigned long long']],
  'MmHighestUserAddress' : [ 0x1c8, ['unsigned long long']],
  'MmSystemRangeStart' : [ 0x1d0, ['unsigned long long']],
  'MmUserProbeAddress' : [ 0x1d8, ['unsigned long long']],
  'KdPrintCircularBuffer' : [ 0x1e0, ['unsigned long long']],
  'KdPrintCircularBufferEnd' : [ 0x1e8, ['unsigned long long']],
  'KdPrintWritePointer' : [ 0x1f0, ['unsigned long long']],
  'KdPrintRolloverCount' : [ 0x1f8, ['unsigned long long']],
  'MmLoadedUserImageList' : [ 0x200, ['unsigned long long']],
  'NtBuildLab' : [ 0x208, ['unsigned long long']],
  'KiNormalSystemCall' : [ 0x210, ['unsigned long long']],
  'KiProcessorBlock' : [ 0x218, ['unsigned long long']],
  'MmUnloadedDrivers' : [ 0x220, ['unsigned long long']],
  'MmLastUnloadedDriver' : [ 0x228, ['unsigned long long']],
  'MmTriageActionTaken' : [ 0x230, ['unsigned long long']],
  'MmSpecialPoolTag' : [ 0x238, ['unsigned long long']],
  'KernelVerifier' : [ 0x240, ['unsigned long long']],
  'MmVerifierData' : [ 0x248, ['unsigned long long']],
  'MmAllocatedNonPagedPool' : [ 0x250, ['unsigned long long']],
  'MmPeakCommitment' : [ 0x258, ['unsigned long long']],
  'MmTotalCommitLimitMaximum' : [ 0x260, ['unsigned long long']],
  'CmNtCSDVersion' : [ 0x268, ['unsigned long long']],
  'MmPhysicalMemoryBlock' : [ 0x270, ['unsigned long long']],
  'MmSessionBase' : [ 0x278, ['unsigned long long']],
  'MmSessionSize' : [ 0x280, ['unsigned long long']],
  'MmSystemParentTablePage' : [ 0x288, ['unsigned long long']],
  'MmVirtualTranslationBase' : [ 0x290, ['unsigned long long']],
  'OffsetKThreadNextProcessor' : [ 0x298, ['unsigned short']],
  'OffsetKThreadTeb' : [ 0x29a, ['unsigned short']],
  'OffsetKThreadKernelStack' : [ 0x29c, ['unsigned short']],
  'OffsetKThreadInitialStack' : [ 0x29e, ['unsigned short']],
  'OffsetKThreadApcProcess' : [ 0x2a0, ['unsigned short']],
  'OffsetKThreadState' : [ 0x2a2, ['unsigned short']],
  'OffsetKThreadBStore' : [ 0x2a4, ['unsigned short']],
  'OffsetKThreadBStoreLimit' : [ 0x2a6, ['unsigned short']],
  'SizeEProcess' : [ 0x2a8, ['unsigned short']],
  'OffsetEprocessPeb' : [ 0x2aa, ['unsigned short']],
  'OffsetEprocessParentCID' : [ 0x2ac, ['unsigned short']],
  'OffsetEprocessDirectoryTableBase' : [ 0x2ae, ['unsigned short']],
  'SizePrcb' : [ 0x2b0, ['unsigned short']],
  'OffsetPrcbDpcRoutine' : [ 0x2b2, ['unsigned short']],
  'OffsetPrcbCurrentThread' : [ 0x2b4, ['unsigned short']],
  'OffsetPrcbMhz' : [ 0x2b6, ['unsigned short']],
  'OffsetPrcbCpuType' : [ 0x2b8, ['unsigned short']],
  'OffsetPrcbVendorString' : [ 0x2ba, ['unsigned short']],
  'OffsetPrcbProcStateContext' : [ 0x2bc, ['unsigned short']],
  'OffsetPrcbNumber' : [ 0x2be, ['unsigned short']],
  'SizeEThread' : [ 0x2c0, ['unsigned short']],
  'KdPrintCircularBufferPtr' : [ 0x2c8, ['unsigned long long']],
  'KdPrintBufferSize' : [ 0x2d0, ['unsigned long long']],
  'KeLoaderBlock' : [ 0x2d8, ['unsigned long long']],
  'SizePcr' : [ 0x2e0, ['unsigned short']],
  'OffsetPcrSelfPcr' : [ 0x2e2, ['unsigned short']],
  'OffsetPcrCurrentPrcb' : [ 0x2e4, ['unsigned short']],
  'OffsetPcrContainedPrcb' : [ 0x2e6, ['unsigned short']],
  'OffsetPcrInitialBStore' : [ 0x2e8, ['unsigned short']],
  'OffsetPcrBStoreLimit' : [ 0x2ea, ['unsigned short']],
  'OffsetPcrInitialStack' : [ 0x2ec, ['unsigned short']],
  'OffsetPcrStackLimit' : [ 0x2ee, ['unsigned short']],
  'OffsetPrcbPcrPage' : [ 0x2f0, ['unsigned short']],
  'OffsetPrcbProcStateSpecialReg' : [ 0x2f2, ['unsigned short']],
  'GdtR0Code' : [ 0x2f4, ['unsigned short']],
  'GdtR0Data' : [ 0x2f6, ['unsigned short']],
  'GdtR0Pcr' : [ 0x2f8, ['unsigned short']],
  'GdtR3Code' : [ 0x2fa, ['unsigned short']],
  'GdtR3Data' : [ 0x2fc, ['unsigned short']],
  'GdtR3Teb' : [ 0x2fe, ['unsigned short']],
  'GdtLdt' : [ 0x300, ['unsigned short']],
  'GdtTss' : [ 0x302, ['unsigned short']],
  'Gdt64R3CmCode' : [ 0x304, ['unsigned short']],
  'Gdt64R3CmTeb' : [ 0x306, ['unsigned short']],
  'IopNumTriageDumpDataBlocks' : [ 0x308, ['unsigned long long']],
  'IopTriageDumpDataBlocks' : [ 0x310, ['unsigned long long']],
  'VfCrashDataBlock' : [ 0x318, ['unsigned long long']],
  'MmBadPagesDetected' : [ 0x320, ['unsigned long long']],
  'MmZeroedPageSingleBitErrorsDetected' : [ 0x328, ['unsigned long long']],
  'EtwpDebuggerData' : [ 0x330, ['unsigned long long']],
  'OffsetPrcbContext' : [ 0x338, ['unsigned short']],
} ],
}



# Rekall Memory Forensics
# Copyright (C) 2007-2011 Volatile Systems
# Copyright 2013 Google Inc. All Rights Reserved.
#
# Additional Authors:
# Michael Cohen <scudette@users.sourceforge.net>
# Mike Auty <mike.auty@gmail.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or (at
# your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#

# pylint: disable=protected-access

import logging
import os

from rekall.plugins import core
from rekall.plugins.windows import common
from rekall import plugin


class WinPsList(common.WinProcessFilter):
    """List processes for windows."""

    __name = "pslist"

    kdbg = None
    eprocess = None

    def __init__(self, **kwargs):
        """Lists the processes by following the _EPROCESS.PsActiveList.

        In the windows operating system, processes are linked together through a
        doubly linked list. This plugin follows the list around, printing
        information about each process.

        To begin, we need to find any element on the list. This can be done by:

        1) Obtaining the _KDDEBUGGER_DATA64.PsActiveProcessHead - debug
           information.

        2) Finding any _EPROCESS in memory (e.g. through psscan) and following
           its list.

        This plugin supports both approaches.
        """
        super(WinPsList, self).__init__(**kwargs)

    def list_eprocess_from_kdbg(self, kdbg):
        """List the eprocess using the kdbg method."""
        PsActiveList = kdbg.PsActiveProcessHead.dereference_as(
            "_LIST_ENTRY")

        return iter(PsActiveList.list_of_type(
                "_EPROCESS", "ActiveProcessLinks"))

    def list_eprocess_from_eprocess(self, eprocess_offset):
        eprocess = self.profile._EPROCESS(
            offset=eprocess_offset, vm=self.kernel_address_space)

        for task in eprocess.ActiveProcessLinks:
            # TODO: Need to filter out the PsActiveProcessHead (which is not
            # really an _EPROCESS)
            yield task

    def list_eprocess(self):
        if self.eprocess_head:
            return self.list_eprocess_from_eprocess(self.eprocess_head)
        elif self.kdbg:
            return self.list_eprocess_from_kdbg(self.kdbg)

        logging.debug("Unable to list processes using any method.")
        return []

    def render(self, renderer):

        renderer.table_header([("Offset (V)", "offset_v", "[addrpad]"),
                               ("Name", "file_name", "20s"),
                               ("PID", "pid", ">6"),
                               ("PPID", "ppid", ">6"),
                               ("Thds", "thread_count", ">6"),
                               ("Hnds", "handle_count", ">8"),
                               ("Sess", "session_id", ">6"),
                               ("Wow64", "wow64", ">6"),
                               ("Start", "process_create_time", "24"),
                               ("Exit", "process_exit_time", "24")]
                              )

        for task in self.filter_processes():
            renderer.table_row(task.obj_offset,
                               task.ImageFileName,
                               task.UniqueProcessId,
                               task.InheritedFromUniqueProcessId,
                               task.ActiveThreads,
                               task.ObjectTable.HandleCount,
                               task.SessionId,
                               task.IsWow64,
                               task.CreateTime,
                               task.ExitTime,
                               )



class WinDllList(common.WinProcessFilter):
    """Prints a list of dll modules mapped into each process."""

    __name = "dlllist"


    def render(self, renderer):
        for task in self.filter_processes():
            pid = task.UniqueProcessId

            renderer.write(u"*" * 72 + "\n")
            renderer.format(u"{0} pid: {1:6}\n", task.ImageFileName, pid)

            if task.Peb:
                renderer.format(u"Command line : {0}\n",
                                task.Peb.ProcessParameters.CommandLine)

                if task.IsWow64:
                    renderer.write(u"Note: use ldrmodules for listing DLLs "
                                   "in Wow64 processes\n")

                renderer.format(u"{0}\n", task.Peb.CSDVersion)
                renderer.write(u"\n")
                renderer.table_header([("Base", "module_base", "[addrpad]"),
                                       ("Size", "module_size", "[addr]"),
                                       ("Path", "loaded_dll_path", ""),
                                       ])
                for m in task.get_load_modules():
                    renderer.table_row(m.DllBase, m.SizeOfImage, m.FullDllName)
            else:
                renderer.write("Unable to read PEB for task.\n")


class WinMemMap(common.WinProcessFilter):
    """Calculates the memory regions mapped by a process."""

    __name = "memmap"

    @classmethod
    def args(cls, parser):
        """Declare the command line args we need."""
        super(WinMemMap, cls).args(parser)
        parser.add_argument(
            "--coalesce", default=False, action="store_true",
            help="Merge contiguous pages into larger ranges.")

    def __init__(self, coalesce=False, **kwargs):
        """Calculates the memory regions mapped by a process.

        Args:
          coalesce: Merge pages which are contiguous in memory into larger
             ranges.
        """
        self.coalesce = coalesce
        super(WinMemMap, self).__init__(**kwargs)

    def render(self, renderer):
        for task in self.filter_processes():
            renderer.section()
            renderer.RenderProgress("Dumping pid {0}".format(
                    task.UniqueProcessId))

            task_space = task.get_process_address_space()
            renderer.format(u"Process: '{0}' pid: {1:6}\n",
                            task.ImageFileName, task.UniqueProcessId)

            if not task_space:
                renderer.write("Unable to read pages for task.\n")
                continue

            renderer.table_header([("Virtual", "offset_v", "[addrpad]"),
                                   ("Physical", "offset_p", "[addrpad]"),
                                   ("Size", "process_size", "[addr]")])

            if self.coalesce:
                ranges = task_space.get_address_ranges()
            else:
                ranges = task_space.get_available_addresses()

            for virtual_address, length in ranges:
                phys_address = task_space.vtop(virtual_address)
                renderer.table_row(virtual_address, phys_address, length)


class WinMemDump(core.DirectoryDumperMixin, WinMemMap):
    """Dump the addressable memory for a process"""

    __name = "memdump"

    def dump_process(self, eprocess, fd):
        task_as = eprocess.get_process_address_space()

        for virtual_address, length in task_as.get_available_addresses():
            phys_address = task_as.vtop(virtual_address)
            fd.write(self.physical_address_space.read(phys_address, length))

    def render(self, renderer):
        if self.dump_dir is None:
            raise plugin.PluginError("Dump directory not specified.")

        for task in self.filter_processes():
            renderer.section()
            filename = u"{0}_{1:d}.dmp".format(
                task.ImageFileName, task.UniqueProcessId)

            renderer.format(u"Writing {0} {1:6} to {2}\n",
                            task.ImageFileName, task, filename)

            with open(os.path.join(self.dump_dir, filename), 'wb') as fd:
                self.dump_process(task, fd)
